<?php

namespace Teknisa\CMP\Modules\V1\Services;

use Doctrine\ORM\EntityManager;
use \Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use \Zeedhi\Framework\DB\StoredProcedure\Param;

class AlteracaoAprovacaoAfService
{
    protected $entityManager;

    public function __construct(EntityManager $entityManager)
    {
        $this->entityManager = $entityManager;
    }

    public function verificaProdutoInativo($row){
        $sql = "SELECT
                  PRODUTO.CDPRODUTO,
                  PRODFILI.IDPRODATIV
                FROM
                  PRODFILI,
                  PRODUTO
                WHERE
                  (PRODUTO.NRORG     =  :NRORG)           AND
                  (PRODUTO.CDPRODUTO =  :CDPRODUTO)         AND
                  (PRODFILI.CDFILIAL =  :CDFILIAL)        AND
                  (PRODUTO.CDPRODUTO = PRODFILI.CDPRODUTO)  AND
                  (PRODFILI.IDPRODATIV = 'I')

                UNION

                SELECT
                  PRODUTO.CDPRODUTO,
                  PRODUTO.IDPRODATIVPR
                FROM
                  PRODUTO
                WHERE
                  (PRODUTO.NRORG     = :NRORG)            AND
                  (PRODUTO.CDPRODUTO = :CDPRODUTO)        AND
                  (PRODUTO.IDPRODATIVPR = 'N')";

        $params = array(
            "CDPRODUTO" => $row['CDPRODUTO'],
            "CDFILIAL" => $row['CDFILIAL'],
            "NRORG" => $row['NRORG']
        );

        $result = $this->entityManager->getConnection()->fetchAll($sql, $params);
        return $result;
    }

    public function verificaProdutoFornecedor($row){
        $sql = "SELECT
                  COUNT(*) as FORNECEDOR
                FROM
                  PRODFORN,
                  PRODUTO
                WHERE
                  PRODFORN.NRORG     = PRODUTO.NRORG      AND
                  PRODFORN.CDPRODUTO = PRODUTO.CDPRODUTO  AND
                  :CDPRODUTO LIKE PRODUTO.CDARVPROD||'%'  AND
                  PRODFORN.CDFORNECED = :CDFORNECED       AND
                  PRODFORN.NRORG      = :NRORG";

        $params = array(
            "CDPRODUTO" => $row['CDPRODUTO'],
            "CDFORNECED" => $row['CDFORNECED'],
            "NRORG" => $row['NRORG']
        );

        $result = $this->entityManager->getConnection()->fetchAll($sql, $params);
        return $result;
    }

    public function verificaQualificacaoMarca($row){
        $sql = "SELECT
                  QFOMARPROD.CDMARCA
                FROM
                  QFOMARPROD,
                  PARASUPRI
                WHERE
                  (QFOMARPROD.NRORG        = :NRORG)           AND
                  (QFOMARPROD.CDPRODUTO    = :CDPRODUTO)       AND
                  (QFOMARPROD.CDMARCA      = :CDMARCA)         AND
                  (PARASUPRI.CDFILIAL      = :CDFILIAL)        AND
                  ((QFOMARPROD.IDAPRMARPRO = 'N' AND QFOMARPROD.IDAUTMARPRO = 'N') OR
                  ((QFOMARPROD.IDAPRMARPRO = 'S')                AND
                  ((PARASUPRI.IDULTIDTVALQ = 'M'                 AND
                    TO_DATE(:DTAUTOFORN)   > LAST_DAY(QFOMARPROD.DTVALAPROVA)) OR
                    (PARASUPRI.IDULTIDTVALQ  = 'D'                 AND
                    TO_DATE(:DTAUTOFORN)   > QFOMARPROD.DTVALAPROVA))))

                UNION

                SELECT
                  PARASUPRI.CDMARCA
                FROM
                  PARASUPRI
                WHERE
                  PARASUPRI.NRORG       = :NRORG    AND
                  PARASUPRI.CDFILIAL    = :CDFILIAL AND
                  PARASUPRI.IDMARSEMQUA = 'S'         AND
                  NOT EXISTS
                    (SELECT
                      QFOMARPROD.CDMARCA
                    FROM
                      QFOMARPROD
                    WHERE
                      QFOMARPROD.NRORG       = :NRORG     AND
                      QFOMARPROD.CDPRODUTO   = :CDPRODUTO AND
                      QFOMARPROD.CDMARCA     = :CDMARCA)";

        $params = array(
            "NRORG" => $row['NRORG'],
            "CDPRODUTO" => $row['CDPRODUTO'],
            "CDMARCA" => $row['CDMARCA'],
            "CDFILIAL" => $row['CDFILIAL'],
            "DTAUTOFORN" => $row['DTAUTOFORN']
        );

        $result = $this->entityManager->getConnection()->fetchAll($sql, $params);
        return $result;
    }

    public function verificaProdQualificadoForn($row){
        $sql = "SELECT
                  QFOPRODFORN.CDPRODUTO,
                  QFOPRODFORN.CDFORNECED
                FROM
                  QFOPRODFORN,
                  PARASUPRI
                WHERE
                  (PARASUPRI.NRORG          = :NRORG)      AND
                  (PARASUPRI.CDFILIAL       = :CDFILIAL)   AND
                  (QFOPRODFORN.CDPRODUTO    = :CDPRODUTO)  AND
                  (QFOPRODFORN.CDFORNECED   = :CDFORNECED) AND
                  ((QFOPRODFORN.IDFORNAPROV = 'N' AND QFOPRODFORN.IDFORNAUTOR = 'N') OR
                  ((QFOPRODFORN.IDFORNAPROV = 'S') AND
                  ((PARASUPRI.IDULTIDTVALQ  = 'M' AND
                    TO_DATE(:DTAUTOFORN)  > LAST_DAY(QFOPRODFORN.DTVALPRFORN)) OR
                   (PARASUPRI.IDULTIDTVALQ  = 'D' AND
                    TO_DATE(:DTAUTOFORN)  > QFOPRODFORN.DTVALPRFORN))))";

        $params = array(
            "NRORG" => $row['NRORG'],
            "CDPRODUTO" => $row['CDPRODUTO'],
            "CDFORNECED" => $row['CDFORNECED'],
            "CDFILIAL" => $row['CDFILIAL'],
            "DTAUTOFORN" => $row['DTAUTOFORN']
        );

        $result = $this->entityManager->getConnection()->fetchAll($sql, $params);
        return $result;
    }

    public function proceVerificaInconsAfs($cdfildest, $cdfillanc, $nrautoforn){
        $connection = $this->entityManager->getConnection();
        $procedure = new StoredProcedure($connection, 'VERIFICA_INCONS_AFS');
        $procedure->addParam(new Param('P_CDFILDEST', Param::PARAM_INPUT, $cdfildest, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDFILLANC', Param::PARAM_INPUT, $cdfillanc, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRAUTOFORN', Param::PARAM_INPUT, $nrautoforn, Param::PARAM_TYPE_STR));
        $procedure->execute();
    }

    public function proceFechamentoAf($cdfildest, $cdfillanc, $nrautoforn){
        $connection = $this->entityManager->getConnection();
        $procedure = new StoredProcedure($connection, 'FECHAMENTO_AF');
        $procedure->addParam(new Param('P_CDFILDEST', Param::PARAM_INPUT, $cdfildest, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDFILLANC', Param::PARAM_INPUT, $cdfillanc, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRAUTOFORN', Param::PARAM_INPUT, $nrautoforn, Param::PARAM_TYPE_STR));
        $procedure->execute();
    }

    public function proceConsisteOrcamento($cdfildest, $cdfillanc, $nrautoforn){
        $connection = $this->entityManager->getConnection();
        $procedure = new StoredProcedure($connection, 'CONSISTE_ORCAMENTO');
        $procedure->addParam(new Param('P_CDFILDEST', Param::PARAM_INPUT, $cdfildest, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDFILLANC', Param::PARAM_INPUT, $cdfillanc, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRAUTOFORN', Param::PARAM_INPUT, $nrautoforn, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_RETORNO', Param::PARAM_OUTPUT));
        return $procedure->execute();
    }
} 